Transaction

Struct Transaction 

pub struct Transaction { /* private fields */ }
Represents a Kaspa transaction. This is an artificial construct that includes additional transaction-related data such as additional data from UTXOs used by transaction inputs. @category Consensus

Implementations

Source

impl Transaction

pub fn new( id: Option<TransactionId>, version: u16, inputs: Vec<TransactionInput>, outputs: Vec<TransactionOutput>, lock_time: u64, subnetwork_id: SubnetworkId, gas: u64, payload: Vec<u8>, mass: u64, ) -> Result<Self>

pub fn new_with_inner(inner: TransactionInner) -> Self

pub fn inner(&self) -> MutexGuard<'_, TransactionInner>

pub fn id(&self) -> TransactionId

Source

impl Transaction

pub fn is_coinbase(&self) -> bool

Determines whether or not a transaction is a coinbase transaction. A coinbase transaction is a special transaction created by miners that distributes fees and block subsidy to the previous blocks’ miners, and specifies the script_pub_key that will be used to pay the current miner in future blocks.

pub fn finalize(&self) -> Result<TransactionId>

Recompute and finalize the tx id based on updated tx fields

pub fn id_string(&self) -> String

Returns the transaction ID

pub fn constructor(js_value: &TransactionT) -> Result<Transaction, JsError>

pub fn get_inputs_as_js_array(&self) -> TransactionInputArrayAsResultT

pub fn addresses(&self, network_type: &NetworkTypeT) -> Result<AddressArrayT>

Returns a list of unique addresses used by transaction inputs. This method can be used to determine addresses used by transaction inputs in order to select private keys needed for transaction signing.

pub fn set_inputs_from_js_array( &mut self, js_value: &TransactionInputArrayAsArgT, )

pub fn get_outputs_as_js_array(&self) -> TransactionOutputArrayAsResultT

pub fn set_outputs_from_js_array( &mut self, js_value: &TransactionOutputArrayAsArgT, )

pub fn get_version(&self) -> u16

pub fn set_version(&self, v: u16)

pub fn get_lock_time(&self) -> u64

pub fn set_lock_time(&self, v: u64)

pub fn get_gas(&self) -> u64

pub fn set_gas(&self, v: u64)

pub fn get_subnetwork_id_as_hex(&self) -> String

pub fn set_subnetwork_id_from_js_value(&mut self, js_value: JsValue)

pub fn get_payload_as_hex_string(&self) -> String

pub fn set_payload_from_js_value(&mut self, js_value: JsValue)

pub fn get_mass(&self) -> u64

pub fn set_mass(&self, v: u64)

Source

impl Transaction

Source

impl Transaction

pub fn serialize_to_object(&self) -> Result<SerializableTransactionT>

Serializes the transaction to a pure JavaScript Object. The schema of the JavaScript object is defined by {@link ISerializableTransaction}. @see {@link ISerializableTransaction}

pub fn serialize_to_json(&self) -> Result<String>

Serializes the transaction to a JSON string. The schema of the JSON is defined by {@link ISerializableTransaction}.

pub fn serialize_to_json_safe(&self) -> Result<String>

Serializes the transaction to a “Safe” JSON schema where it converts all bigint values to string to avoid potential client-side precision loss.

pub fn deserialize_from_object(js_value: &JsValue) -> Result<Transaction>

Deserialize the {@link Transaction} Object from a pure JavaScript Object.

pub fn deserialize_from_json(json: &str) -> Result<Transaction>

Deserialize the {@link Transaction} Object from a JSON string.

pub fn deserialize_from_safe_json(json: &str) -> Result<Transaction>

Deserialize the {@link Transaction} Object from a “Safe” JSON schema where all bigint values are represented as string.